@@ -137,12 +137,8 @@ def orderlineview(request, orderline_id=None):
         else:
             new_orderline = OrderLineForm(request.POST, auto_id=True)
     else:
-        if orderline_id:
-            form = OrderLineForm(instance=orderline)
-            form.fields["users"].queryset = get_order().available_users()
-        else:
-            form = OrderLineForm(instance=orderline)
-            form.fields["users"].queryset = get_order().available_users()
+        form = OrderLineForm(instance=orderline)
+        form.fields["users"].queryset = get_order().available_users().exclude(id=request.user.id)
     return render(request, 'orderview.html', {'form': form, 'is_admin': is_admin(request)})
 
 
@@ -268,9 +264,20 @@ def manage_order(request):
                 orderline.users.add(orderline.creator)
                 orderline.each = orderline.get_total_price() / (orderline.users.count())
                 total_price += orderline.price
-            if request.POST['act'] == 'load':
+            if request.POST['act'] == 'Load':
                 return render(request, 'manage_order.html', {'form': form, 'is_admin': is_admin(request), 'order': order, 'orderlines': orderlines, 'total_price': total_price})
-            elif request.POST['act'] == 'pay':
+            elif request.POST['act'] == 'Edit':
+                for rq in request.POST:
+                    if 'edit_orderline_price' in rq:
+                        i = rq.split('-')[1]
+                        ol = orderlines.get(id=i)
+                        change = int(request.POST[rq])
+                        if ol.price != change:
+                            ol.price = change
+                            ol.save()
+                            messages.success(request, 'Changed price for %(ol)s to %(price)s' % {'ol': ol, 'price': ol.price})
+                return redirect(manage_order)
+            elif request.POST['act'] == 'Pay':
                 handle_payment(request, order)
                 return redirect(manage_order)
         else:
@@ -377,10 +384,11 @@ def check_orderline(request, form, orderline_id=None, buddies=None):
     else:
         users.extend(buddies)
     amount = amount / len(users)
-    for user in users:
-        if not validate_user_funds(user, amount):
-            messages.error(request, 'Unsufficient funds caught for %s' % user.get_username())
-            return False
+    if get_order().use_validation:
+        for user in users:
+            if not validate_user_funds(user, amount):
+                messages.error(request, 'Unsufficient funds caught for %s' % user.get_username())
+                return False
     return True
 
 
